@@ -594,7 +594,7 @@ pub mod macros {
         };};
     }
 
-    /// vec_parse!() used to remove file or folder
+    /// vec_element_convert!() used convert vec elements type
     /// ```rust
     /// use useful_macro::*;
     ///let v1: Vec<f64> = vec_element_convert!(vec![1, 2], f64);
@@ -625,7 +625,8 @@ pub mod macros {
     }
 
     pub fn run() {
-        vec_element_convert!(vec![0], f64);
+        let re = vec_element_to_string!(vec_element_convert!(vec![15, 56, 14, 14], f64));
+        println!("{:?}", re);
     }
 }
 
